@@ -1,8 +1,5 @@
-#[macro_use(mem_info)]
-extern crate arrayfire as af;
-
+use arrayfire::*;
 use std::time::Instant;
-use af::*;
 
 #[allow(unused_must_use)]
 #[allow(unused_variables)]
@@ -25,8 +22,8 @@ fn main() {
         let xplusy = &add(xsqrd, ysqrd, false);
         let root = &sqrt(xplusy);
         let cnst = &constant(1, dims);
-        let (real, imag) = sum_all(&le(root, cnst, false)); 
-        let pi_val = real*4.0/(samples as f64);
+        let (real, imag) = sum_all(&le(root, cnst, false));
+        let pi_val = real * 4.0 / (samples as f64);
     }
 
     println!("Estimated Pi Value in {:?}", start.elapsed());
