@@ -1,14 +1,14 @@
 extern crate libc;
 
-use array::Array;
-use defines::{AfError, BinaryOp};
-use error::HANDLE_ERROR;
-use self::libc::{c_int, c_uint, c_double};
-use util::{AfArray, MutAfArray, MutDouble, MutUint};
-use util::{HasAfEnum, Scanable, RealNumber};
+use self::libc::{c_double, c_int, c_uint};
+use crate::array::Array;
+use crate::defines::{AfError, BinaryOp};
+use crate::error::HANDLE_ERROR;
+use crate::util::{AfArray, MutAfArray, MutDouble, MutUint};
+use crate::util::{HasAfEnum, RealNumber, Scanable};
 
 #[allow(dead_code)]
-extern {
+extern "C" {
     fn af_sum(out: MutAfArray, input: AfArray, dim: c_int) -> c_int;
     fn af_sum_nan(out: MutAfArray, input: AfArray, dim: c_int, nanval: c_double) -> c_int;
     fn af_product(out: MutAfArray, input: AfArray, dim: c_int) -> c_int;
@@ -41,33 +41,51 @@ extern {
     fn af_set_union(out: MutAfArray, first: AfArray, second: AfArray, is_unq: c_int) -> c_int;
     fn af_set_intersect(out: MutAfArray, one: AfArray, two: AfArray, is_unq: c_int) -> c_int;
 
-    fn af_sort_by_key(out_keys: MutAfArray, out_vals: MutAfArray,
-                      in_keys: AfArray, in_vals: AfArray, dim: c_uint, ascend: c_int) -> c_int;
+    fn af_sort_by_key(
+        out_keys: MutAfArray,
+        out_vals: MutAfArray,
+        in_keys: AfArray,
+        in_vals: AfArray,
+        dim: c_uint,
+        ascend: c_int,
+    ) -> c_int;
 
     fn af_scan(out: MutAfArray, inp: AfArray, dim: c_int, op: c_uint, inclusive: c_int) -> c_int;
-    fn af_scan_by_key(out: MutAfArray, key: AfArray, inp: AfArray,
-                      dim: c_int, op: c_uint, inclusive: c_int) -> c_int;
+    fn af_scan_by_key(
+        out: MutAfArray,
+        key: AfArray,
+        inp: AfArray,
+        dim: c_int,
+        op: c_uint,
+        inclusive: c_int,
+    ) -> c_int;
 }
 
 macro_rules! dim_reduce_func_def {
-    ($doc_str: expr, $fn_name: ident, $ffi_name: ident, $out_type: ty) => (
+    ($doc_str: expr, $fn_name: ident, $ffi_name: ident, $out_type: ty) => {
         #[doc=$doc_str]
         #[allow(unused_mut)]
-        pub fn $fn_name<T>(input: &Array<T>, dim: i32) -> Array< $out_type >
-            where T: HasAfEnum, $out_type: HasAfEnum
+        pub fn $fn_name<T>(input: &Array<T>, dim: i32) -> Array<$out_type>
+        where
+            T: HasAfEnum,
+            $out_type: HasAfEnum,
         {
             let mut temp: i64 = 0;
             unsafe {
-                let err_val = $ffi_name(&mut temp as MutAfArray,
-                                        input.get() as AfArray, dim as c_int);
+                let err_val = $ffi_name(
+                    &mut temp as MutAfArray,
+                    input.get() as AfArray,
+                    dim as c_int,
+                );
                 HANDLE_ERROR(AfError::from(err_val));
             }
             temp.into()
         }
-    )
+    };
 }
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Sum elements along a given dimension
 
     # Parameters
@@ -92,9 +110,13 @@ dim_reduce_func_def!("
     print(&c);
     ```
     ",
-    sum, af_sum, T::AggregateOutType);
+    sum,
+    af_sum,
+    T::AggregateOutType
+);
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Compute product of elements along a given dimension
 
     # Parameters
@@ -118,9 +140,14 @@ dim_reduce_func_def!("
     let c = product(&a, 1);
     print(&c);
     ```
-    ", product, af_product, T::AggregateOutType);
+    ",
+    product,
+    af_product,
+    T::AggregateOutType
+);
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Find minimum among elements of given dimension
 
     # Parameters
@@ -144,9 +171,14 @@ dim_reduce_func_def!("
     let c = min(&a, 1);
     print(&c);
     ```
-    ", min, af_min, T::InType);
+    ",
+    min,
+    af_min,
+    T::InType
+);
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Find maximum among elements of given dimension
 
     # Parameters
@@ -170,9 +202,14 @@ dim_reduce_func_def!("
     let c = max(&a, 1);
     print(&c);
     ```
-    ", max, af_max, T::InType);
+    ",
+    max,
+    af_max,
+    T::InType
+);
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Find if all of the values along a given dimension in the Array are true
 
     # Parameters
@@ -196,9 +233,14 @@ dim_reduce_func_def!("
     let c = all_true(&a, 1);
     print(&c);
     ```
-    ", all_true, af_all_true, bool);
+    ",
+    all_true,
+    af_all_true,
+    bool
+);
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Find if any of the values along a given dimension in the Array are true
 
     # Parameters
@@ -222,9 +264,14 @@ dim_reduce_func_def!("
     let c = any_true(&a, 1);
     print(&c);
     ```
-    ", any_true, af_any_true, bool);
+    ",
+    any_true,
+    af_any_true,
+    bool
+);
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Count number of non-zero elements along a given dimension
 
     # Parameters
@@ -249,9 +296,14 @@ dim_reduce_func_def!("
     let c = count(&a, 1);
     print(&c);
     ```
-    ", count, af_count, u32);
+    ",
+    count,
+    af_count,
+    u32
+);
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Perform exclusive sum of elements along a given dimension
 
     # Parameters
@@ -275,9 +327,14 @@ dim_reduce_func_def!("
     let c = accum(&a, 1);
     print(&c);
     ```
-    ", accum, af_accum, T::AggregateOutType);
+    ",
+    accum,
+    af_accum,
+    T::AggregateOutType
+);
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Calculate first order numerical difference along a given dimension
 
     # Parameters
@@ -301,9 +358,14 @@ dim_reduce_func_def!("
     let c = diff1(&a, 1);
     print(&c);
     ```
-    ", diff1, af_diff1, T::InType);
+    ",
+    diff1,
+    af_diff1,
+    T::InType
+);
 
-dim_reduce_func_def!("
+dim_reduce_func_def!(
+    "
     Calculate second order numerical difference along a given dimension
 
     # Parameters
@@ -327,7 +389,11 @@ dim_reduce_func_def!("
     let c = diff2(&a, 1);
     print(&c);
     ```
-    ", diff2, af_diff2, T::InType);
+    ",
+    diff2,
+    af_diff2,
+    T::InType
+);
 
 /// Sum along specific dimension using user specified value instead of `NAN` values
 ///
@@ -343,15 +409,19 @@ dim_reduce_func_def!("
 /// # Return Values
 ///
 /// Array that is reduced along given dimension via addition operation
-pub fn sum_nan<T>(input: &Array<T>,
-                  dim: i32, nanval: f64) -> Array< T::AggregateOutType >
-    where T: HasAfEnum,
-          T::AggregateOutType: HasAfEnum
+pub fn sum_nan<T>(input: &Array<T>, dim: i32, nanval: f64) -> Array<T::AggregateOutType>
+where
+    T: HasAfEnum,
+    T::AggregateOutType: HasAfEnum,
 {
     let mut temp: i64 = 0;
     unsafe {
-        let err_val = af_sum_nan(&mut temp as MutAfArray, input.get() as AfArray,
-                                 dim as c_int, nanval as c_double);
+        let err_val = af_sum_nan(
+            &mut temp as MutAfArray,
+            input.get() as AfArray,
+            dim as c_int,
+            nanval as c_double,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     temp.into()
@@ -370,39 +440,46 @@ pub fn sum_nan<T>(input: &Array<T>,
 /// # Return Values
 ///
 /// Array that is reduced along given dimension via multiplication operation
-pub fn product_nan<T>(input: &Array<T>,
-                      dim: i32, nanval: f64) -> Array< T::AggregateOutType >
-    where T: HasAfEnum,
-          T::AggregateOutType: HasAfEnum
+pub fn product_nan<T>(input: &Array<T>, dim: i32, nanval: f64) -> Array<T::AggregateOutType>
+where
+    T: HasAfEnum,
+    T::AggregateOutType: HasAfEnum,
 {
     let mut temp: i64 = 0;
     unsafe {
-        let err_val = af_product_nan(&mut temp as MutAfArray, input.get() as AfArray,
-                                     dim as c_int, nanval as c_double);
+        let err_val = af_product_nan(
+            &mut temp as MutAfArray,
+            input.get() as AfArray,
+            dim as c_int,
+            nanval as c_double,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     temp.into()
 }
 
 macro_rules! all_reduce_func_def {
-    ($doc_str: expr, $fn_name: ident, $ffi_name: ident) => (
+    ($doc_str: expr, $fn_name: ident, $ffi_name: ident) => {
         #[doc=$doc_str]
         #[allow(unused_mut)]
-        pub fn $fn_name<T:HasAfEnum>(input: &Array<T>) -> (f64, f64) {
+        pub fn $fn_name<T: HasAfEnum>(input: &Array<T>) -> (f64, f64) {
             let mut real: f64 = 0.0;
             let mut imag: f64 = 0.0;
             unsafe {
-                let err_val = $ffi_name(&mut real as MutDouble,
-                                        &mut imag as MutDouble,
-                                        input.get() as AfArray);
+                let err_val = $ffi_name(
+                    &mut real as MutDouble,
+                    &mut imag as MutDouble,
+                    input.get() as AfArray,
+                );
                 HANDLE_ERROR(AfError::from(err_val));
             }
             (real, imag)
         }
-    )
+    };
 }
 
-all_reduce_func_def!("
+all_reduce_func_def!(
+    "
     Sum all values of the Array
 
     # Parameters
@@ -424,9 +501,13 @@ all_reduce_func_def!("
     print(&a);
     println!(\"Result : {:?}\", sum_all(&a));
     ```
-    ", sum_all, af_sum_all);
+    ",
+    sum_all,
+    af_sum_all
+);
 
-all_reduce_func_def!("
+all_reduce_func_def!(
+    "
     Product of all values of the Array
 
     # Parameters
@@ -448,9 +529,13 @@ all_reduce_func_def!("
     print(&a);
     println!(\"Result : {:?}\", product_all(&a));
     ```
-    ", product_all, af_product_all);
+    ",
+    product_all,
+    af_product_all
+);
 
-all_reduce_func_def!("
+all_reduce_func_def!(
+    "
     Find minimum among all values of the Array
 
     # Parameters
@@ -472,9 +557,13 @@ all_reduce_func_def!("
     print(&a);
     println!(\"Result : {:?}\", min_all(&a));
     ```
-    ", min_all, af_min_all);
+    ",
+    min_all,
+    af_min_all
+);
 
-all_reduce_func_def!("
+all_reduce_func_def!(
+    "
     Find maximum among all values of the Array
 
     # Parameters
@@ -496,9 +585,13 @@ all_reduce_func_def!("
     print(&a);
     println!(\"Result : {:?}\", max_all(&a));
     ```
-    ", max_all, af_max_all);
+    ",
+    max_all,
+    af_max_all
+);
 
-all_reduce_func_def!("
+all_reduce_func_def!(
+    "
     Find if all values of Array are non-zero
 
     # Parameters
@@ -518,9 +611,13 @@ all_reduce_func_def!("
     print(&a);
     println!(\"Result : {:?}\", all_true_all(&a));
     ```
-    ", all_true_all, af_all_true_all);
+    ",
+    all_true_all,
+    af_all_true_all
+);
 
-all_reduce_func_def!("
+all_reduce_func_def!(
+    "
     Find if any value of Array is non-zero
 
     # Parameters
@@ -540,9 +637,13 @@ all_reduce_func_def!("
     print(&a);
     println!(\"Result : {:?}\", any_true_all(&a));
     ```
-    ", any_true_all, af_any_true_all);
+    ",
+    any_true_all,
+    af_any_true_all
+);
 
-all_reduce_func_def!("
+all_reduce_func_def!(
+    "
     Count number of non-zero values in the Array
 
     # Parameters
@@ -562,7 +663,10 @@ all_reduce_func_def!("
     print(&a);
     println!(\"Result : {:?}\", count_all(&a));
     ```
-    ", count_all, af_count_all);
+    ",
+    count_all,
+    af_count_all
+);
 
 /// Sum all values using user provided value for `NAN`
 ///
@@ -583,8 +687,12 @@ pub fn sum_nan_all<T: HasAfEnum>(input: &Array<T>, val: f64) -> (f64, f64) {
     let mut real: f64 = 0.0;
     let mut imag: f64 = 0.0;
     unsafe {
-        let err_val = af_sum_nan_all(&mut real as MutDouble, &mut imag as MutDouble,
-                                     input.get() as AfArray, val as c_double);
+        let err_val = af_sum_nan_all(
+            &mut real as MutDouble,
+            &mut imag as MutDouble,
+            input.get() as AfArray,
+            val as c_double,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     (real, imag)
@@ -609,31 +717,40 @@ pub fn product_nan_all<T: HasAfEnum>(input: &Array<T>, val: f64) -> (f64, f64) {
     let mut real: f64 = 0.0;
     let mut imag: f64 = 0.0;
     unsafe {
-        let err_val = af_product_nan_all(&mut real as MutDouble, &mut imag as MutDouble,
-                                         input.get() as AfArray, val as c_double);
+        let err_val = af_product_nan_all(
+            &mut real as MutDouble,
+            &mut imag as MutDouble,
+            input.get() as AfArray,
+            val as c_double,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     (real, imag)
 }
 
 macro_rules! dim_ireduce_func_def {
-    ($doc_str: expr, $fn_name: ident, $ffi_name: ident, $out_type: ident) => (
+    ($doc_str: expr, $fn_name: ident, $ffi_name: ident, $out_type: ident) => {
         #[doc=$doc_str]
         #[allow(unused_mut)]
-        pub fn $fn_name<T>(input: &Array<T>, dim: i32) -> (Array< T::$out_type >, Array<u32>)
-            where T: HasAfEnum,
-                  T::$out_type: HasAfEnum
+        pub fn $fn_name<T>(input: &Array<T>, dim: i32) -> (Array<T::$out_type>, Array<u32>)
+        where
+            T: HasAfEnum,
+            T::$out_type: HasAfEnum,
         {
             let mut temp: i64 = 0;
             let mut idx: i64 = 0;
             unsafe {
-                let err_val = $ffi_name(&mut temp as MutAfArray, &mut idx as MutAfArray,
-                                        input.get() as AfArray, dim as c_int);
+                let err_val = $ffi_name(
+                    &mut temp as MutAfArray,
+                    &mut idx as MutAfArray,
+                    input.get() as AfArray,
+                    dim as c_int,
+                );
                 HANDLE_ERROR(AfError::from(err_val));
             }
             (temp.into(), idx.into())
         }
-    )
+    };
 }
 
 dim_ireduce_func_def!("
@@ -663,24 +780,29 @@ dim_ireduce_func_def!("
     ", imax, af_imax, InType);
 
 macro_rules! all_ireduce_func_def {
-    ($doc_str: expr, $fn_name: ident, $ffi_name: ident) => (
+    ($doc_str: expr, $fn_name: ident, $ffi_name: ident) => {
         #[doc=$doc_str]
         #[allow(unused_mut)]
-        pub fn $fn_name<T:HasAfEnum>(input: &Array<T>) -> (f64, f64, u32) {
+        pub fn $fn_name<T: HasAfEnum>(input: &Array<T>) -> (f64, f64, u32) {
             let mut real: f64 = 0.0;
             let mut imag: f64 = 0.0;
             let mut temp: u32 = 0;
             unsafe {
-                let err_val = $ffi_name(&mut real as MutDouble, &mut imag as MutDouble,
-                                        &mut temp as MutUint, input.get() as AfArray);
+                let err_val = $ffi_name(
+                    &mut real as MutDouble,
+                    &mut imag as MutDouble,
+                    &mut temp as MutUint,
+                    input.get() as AfArray,
+                );
                 HANDLE_ERROR(AfError::from(err_val));
             }
             (real, imag, temp)
         }
-    )
+    };
 }
 
-all_ireduce_func_def!("
+all_ireduce_func_def!(
+    "
     Find minimum and it's index in the whole Array
 
     # Parameters
@@ -694,8 +816,12 @@ all_ireduce_func_def!("
       * minimum element of Array in the first component.
       * second component of value zero if Array is of non-complex type.
       * index of minimum element in the third component.
-    ", imin_all, af_imin_all);
-all_ireduce_func_def!("
+    ",
+    imin_all,
+    af_imin_all
+);
+all_ireduce_func_def!(
+    "
     Find maximum and it's index in the whole Array
 
     # Parameters
@@ -709,7 +835,10 @@ all_ireduce_func_def!("
       - maximum element of Array in the first component.
       - second component of value zero if Array is of non-complex type.
       - index of maximum element in the third component.
-    ", imax_all, af_imax_all);
+    ",
+    imax_all,
+    af_imax_all
+);
 
 /// Locate the indices of non-zero elements.
 ///
@@ -723,7 +852,7 @@ all_ireduce_func_def!("
 ///
 /// Array of indices where the input Array has non-zero values.
 #[allow(unused_mut)]
-pub fn locate<T:HasAfEnum>(input: &Array<T>) -> Array<u32> {
+pub fn locate<T: HasAfEnum>(input: &Array<T>) -> Array<u32> {
     let mut temp: i64 = 0;
     unsafe {
         let err_val = af_where(&mut temp as MutAfArray, input.get() as AfArray);
@@ -748,12 +877,17 @@ pub fn locate<T:HasAfEnum>(input: &Array<T>) -> Array<u32> {
 /// Sorted Array.
 #[allow(unused_mut)]
 pub fn sort<T>(input: &Array<T>, dim: u32, ascending: bool) -> Array<T>
-    where T: HasAfEnum + RealNumber
+where
+    T: HasAfEnum + RealNumber,
 {
     let mut temp: i64 = 0;
     unsafe {
-        let err_val = af_sort(&mut temp as MutAfArray, input.get() as AfArray,
-                              dim as c_uint, ascending as c_int);
+        let err_val = af_sort(
+            &mut temp as MutAfArray,
+            input.get() as AfArray,
+            dim as c_uint,
+            ascending as c_int,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     temp.into()
@@ -777,15 +911,19 @@ pub fn sort<T>(input: &Array<T>, dim: u32, ascending: bool) -> Array<T>
 /// The second Array contains the original indices of the sorted values.
 #[allow(unused_mut)]
 pub fn sort_index<T>(input: &Array<T>, dim: u32, ascending: bool) -> (Array<T>, Array<u32>)
-    where T: HasAfEnum + RealNumber
+where
+    T: HasAfEnum + RealNumber,
 {
     let mut temp: i64 = 0;
     let mut idx: i64 = 0;
     unsafe {
-        let err_val = af_sort_index(&mut temp as MutAfArray,
-                                    &mut idx as MutAfArray,
-                                    input.get() as AfArray,
-                                    dim as c_uint, ascending as c_int);
+        let err_val = af_sort_index(
+            &mut temp as MutAfArray,
+            &mut idx as MutAfArray,
+            input.get() as AfArray,
+            dim as c_uint,
+            ascending as c_int,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     (temp.into(), idx.into())
@@ -810,19 +948,27 @@ pub fn sort_index<T>(input: &Array<T>, dim: u32, ascending: bool) -> (Array<T>,
 ///
 /// The second Array contains the sorted values.
 #[allow(unused_mut)]
-pub fn sort_by_key<K, V>(keys: &Array<K>, vals: &Array<V>, dim: u32,
-                         ascending: bool) -> (Array<K>, Array<V>)
-    where K: HasAfEnum + RealNumber,
-          V: HasAfEnum
+pub fn sort_by_key<K, V>(
+    keys: &Array<K>,
+    vals: &Array<V>,
+    dim: u32,
+    ascending: bool,
+) -> (Array<K>, Array<V>)
+where
+    K: HasAfEnum + RealNumber,
+    V: HasAfEnum,
 {
     let mut temp: i64 = 0;
     let mut temp2: i64 = 0;
     unsafe {
-        let err_val = af_sort_by_key(&mut temp as MutAfArray,
-                                     &mut temp2 as MutAfArray,
-                                     keys.get() as AfArray,
-                                     vals.get() as AfArray,
-                                     dim as c_uint, ascending as c_int);
+        let err_val = af_sort_by_key(
+            &mut temp as MutAfArray,
+            &mut temp2 as MutAfArray,
+            keys.get() as AfArray,
+            vals.get() as AfArray,
+            dim as c_uint,
+            ascending as c_int,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     (temp.into(), temp2.into())
@@ -841,13 +987,16 @@ pub fn sort_by_key<K, V>(keys: &Array<K>, vals: &Array<V>, dim: u32,
 /// An Array of unique values from the input Array.
 #[allow(unused_mut)]
 pub fn set_unique<T>(input: &Array<T>, is_sorted: bool) -> Array<T>
-    where T: HasAfEnum + RealNumber
+where
+    T: HasAfEnum + RealNumber,
 {
     let mut temp: i64 = 0;
     unsafe {
-        let err_val = af_set_unique(&mut temp as MutAfArray,
-                                    input.get() as AfArray,
-                                    is_sorted as c_int);
+        let err_val = af_set_unique(
+            &mut temp as MutAfArray,
+            input.get() as AfArray,
+            is_sorted as c_int,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     temp.into()
@@ -866,12 +1015,17 @@ pub fn set_unique<T>(input: &Array<T>, is_sorted: bool) -> Array<T>
 /// An Array with union of the input sets
 #[allow(unused_mut)]
 pub fn set_union<T>(first: &Array<T>, second: &Array<T>, is_unique: bool) -> Array<T>
-    where T: HasAfEnum + RealNumber
+where
+    T: HasAfEnum + RealNumber,
 {
     let mut temp: i64 = 0;
     unsafe {
-        let err_val = af_set_union(&mut temp as MutAfArray, first.get() as AfArray,
-                                   second.get() as AfArray, is_unique as c_int);
+        let err_val = af_set_union(
+            &mut temp as MutAfArray,
+            first.get() as AfArray,
+            second.get() as AfArray,
+            is_unique as c_int,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     temp.into()
@@ -890,12 +1044,17 @@ pub fn set_union<T>(first: &Array<T>, second: &Array<T>, is_unique: bool) -> Arr
 /// An Array with intersection of the input sets
 #[allow(unused_mut)]
 pub fn set_intersect<T>(first: &Array<T>, second: &Array<T>, is_unique: bool) -> Array<T>
-    where T: HasAfEnum + RealNumber
+where
+    T: HasAfEnum + RealNumber,
 {
     let mut temp: i64 = 0;
     unsafe {
-        let err_val = af_set_intersect(&mut temp as MutAfArray, first.get() as AfArray,
-                                       second.get() as AfArray, is_unique as c_int);
+        let err_val = af_set_intersect(
+            &mut temp as MutAfArray,
+            first.get() as AfArray,
+            second.get() as AfArray,
+            is_unique as c_int,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     temp.into()
@@ -914,15 +1073,25 @@ pub fn set_intersect<T>(first: &Array<T>, second: &Array<T>, is_unique: bool) ->
 /// # Return Values
 ///
 /// Output Array of scanned input
-pub fn scan<T>(input: &Array<T>, dim: i32,
-               op: BinaryOp, inclusive: bool) -> Array< T::AggregateOutType >
-    where T: HasAfEnum,
-          T::AggregateOutType: HasAfEnum
+pub fn scan<T>(
+    input: &Array<T>,
+    dim: i32,
+    op: BinaryOp,
+    inclusive: bool,
+) -> Array<T::AggregateOutType>
+where
+    T: HasAfEnum,
+    T::AggregateOutType: HasAfEnum,
 {
-    let mut temp : i64 = 0;
+    let mut temp: i64 = 0;
     unsafe {
-        let err_val = af_scan(&mut temp as MutAfArray, input.get() as AfArray,
-                              dim as c_int, op as c_uint, inclusive as c_int);
+        let err_val = af_scan(
+            &mut temp as MutAfArray,
+            input.get() as AfArray,
+            dim as c_int,
+            op as c_uint,
+            inclusive as c_int,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     temp.into()
@@ -942,18 +1111,28 @@ pub fn scan<T>(input: &Array<T>, dim: i32,
 /// # Return Values
 ///
 /// Output Array of scanned input
-pub fn scan_by_key<K, V>(key: &Array<K>, input: &Array<V>,
-                         dim: i32, op: BinaryOp,
-                         inclusive: bool) -> Array< V::AggregateOutType >
-    where V: HasAfEnum,
-          V::AggregateOutType: HasAfEnum,
-          K: HasAfEnum + Scanable
+pub fn scan_by_key<K, V>(
+    key: &Array<K>,
+    input: &Array<V>,
+    dim: i32,
+    op: BinaryOp,
+    inclusive: bool,
+) -> Array<V::AggregateOutType>
+where
+    V: HasAfEnum,
+    V::AggregateOutType: HasAfEnum,
+    K: HasAfEnum + Scanable,
 {
-    let mut temp : i64 = 0;
+    let mut temp: i64 = 0;
     unsafe {
-        let err_val = af_scan_by_key(&mut temp as MutAfArray, key.get() as AfArray,
-                                     input.get() as AfArray, dim as c_int,
-                                     op as c_uint, inclusive as c_int);
+        let err_val = af_scan_by_key(
+            &mut temp as MutAfArray,
+            key.get() as AfArray,
+            input.get() as AfArray,
+            dim as c_int,
+            op as c_uint,
+            inclusive as c_int,
+        );
         HANDLE_ERROR(AfError::from(err_val));
     }
     temp.into()
